##### System Health Check #####
# Written by Chad Jordan
# 5-12-2018

Add-Type -AssemblyName PresentationFramework

$Window = New-Object System.Windows.Window
$Window.Title = "System Health Monitor"
$Window.Width = 600
$Window.Height = 450

$StackPanel = New-Object System.Windows.Controls.StackPanel
$Window.Content = $StackPanel

$TitleLabel = New-Object System.Windows.Controls.Label
$TitleLabel.Content = "System Health Monitor"
$TitleLabel.FontSize = 18
$StackPanel.Children.Add($TitleLabel)

$TextBox = New-Object System.Windows.Controls.TextBox
$TextBox.Width = 550
$TextBox.Height = 200
$TextBox.IsReadOnly = $true
$TextBox.TextWrapping = "Wrap"
$StackPanel.Children.Add($TextBox)

$AutoRunCheckbox = New-Object System.Windows.Controls.CheckBox
$AutoRunCheckbox.Content = "Enable Auto-Run (Every 10 minutes)"
$AutoRunCheckbox.IsChecked = $false
$StackPanel.Children.Add($AutoRunCheckbox)

$AutoRunCheckbox.Add_Checked({
    $timer.Start() 
    [System.Windows.MessageBox]::Show("Auto-Run Enabled! The system health check will run every 10 minutes.")
})

#Disable Auto-Run When Unchecked
$AutoRunCheckbox.Add_Unchecked({
    $timer.Stop() 
    [System.Windows.MessageBox]::Show("Auto-Run Disabled!")
})

#Create a Timer Object (Runs Every 10 Minutes)
$timer = New-Object System.Windows.Threading.DispatcherTimer
$timer.Interval = [TimeSpan]::FromMinutes(10)
$timer.Add_Tick({ Run-HealthCheck })

$StartButton = New-Object System.Windows.Controls.Button
$StartButton.Content = "Run Health Check"
$StartButton.Width = 150
$StartButton.Add_Click({ Run-HealthCheck })
$StackPanel.Children.Add($StartButton)

$EmailButton = New-Object System.Windows.Controls.Button
$EmailButton.Content = "Send Report via Email"
$EmailButton.Width = 200
$EmailButton.Add_Click({ Send-Email })
$StackPanel.Children.Add($EmailButton)

#Function to Run Health Check
function Run-HealthCheck {
    $TextBox.Text = "Running Health Check..."
    Start-Sleep -Seconds 2

    $cpu = Get-Counter '\Processor(_Total)\% Processor Time' | Select-Object -ExpandProperty CounterSamples | Select-Object -ExpandProperty CookedValue
    $memory = Get-Counter '\Memory\Available MBytes' | Select-Object -ExpandProperty CounterSamples | Select-Object -ExpandProperty CookedValue
    $diskSpace = Get-PSDrive C | Select-Object Used, Free
    $freeSpaceGB = [math]::Round($diskSpace.Free / 1GB, 2)
    $uptime = (Get-CimInstance Win32_OperatingSystem).LastBootUpTime

    $report = "System Health Report`n------------------`n"
    $report += "CPU Usage: $([math]::Round($cpu,2))%`n"
    $report += "Available Memory: $([math]::Round($memory,2)) MB`n"
    $report += "Disk Space Free: $freeSpaceGB GB`n"
    $report += "System Uptime: $uptime`n"

    #Display Report
    $TextBox.Text = $report

    #Ensure the directory exists
    $reportDir = "C:\ITReports"
        if (!(Test-Path -Path $reportDir)) {
        New-Item -ItemType Directory -Path $reportDir -Force
}
    #Define report path
    $reportPath = "$reportDir\SystemHealth_$env:COMPUTERNAME.txt"

    #Save Report to File
    $reportPath = "C:\ITReports\SystemHealth_$env:COMPUTERNAME.txt"
    $report | Out-File -FilePath $reportPath -Encoding UTF8
}

function Send-Email {
    $smtpServer = "smtp.example.com"
    $from = "admin@example.com"
    $to = "itteam@example.com"
    $subject = "System Health Report"
    $body = $TextBox.Text

    Send-MailMessage -SmtpServer $smtpServer -From $from -To $to -Subject $subject -Body $body -Credential (Get-Credential) -UseSsl
    [System.Windows.MessageBox]::Show("Report Sent!")
}

#Function to Auto-Run Health Check Every 10 Minutes
$scriptBlock = {
    while ($true) {
        if ($AutoRunCheckbox.IsChecked) {
            Run-HealthCheck
            Send-Email
        }
        Start-Sleep -Seconds 600 
    }
}
Start-Job -ScriptBlock $scriptBlock

$Window.ShowDialog()
